@@ -1,3 +1,3 @@
 """A module for nice looking colored logs. Licensed under MIT license (see LICENSE for details)."""
 
-from .colorlog import Logger, OK
+from .colorlog import Logger, FileLogger, OK
